@@ -23,23 +23,15 @@ class Project:
 def pytest_sessionstart(session):
     Project.dir = session.config.cache.get("project_dir", None)
     if not Project.dir:
-        # First time run, no pytest_cache, use tests directory to find project directory
+        # First time run, no pytest_cache
         cwd = os.getcwd()
         tests = cwd.find("tests")
-        if tests == -1:
-            raise FileNotFoundError("'tests' directory not found.")
-        else:
+        # tests
+        if tests:
             Project.dir = cwd[:cwd.find("tests")]
-
-
-@pytest.fixture(scope="session")
-def url(env_vars):
-    def domain_and_api_path(api_path):
-        if not api_path.startswith("/"):
-            api_path = "/" + api_path
-        return env_vars.domain + api_path
-
-    return domain_and_api_path
+        # root
+        else:
+            Project.dir = cwd
 
 
 @pytest.fixture(scope="session")
