@@ -8,12 +8,16 @@
 """
 
 import os
-import shutil
+import platform
 import sys
 
 from loguru import logger
 
 
+class ExtraArgument:
+    create_venv = False
+
+
 def init_parser_scaffold(subparsers):
     sub_parser_scaffold = subparsers.add_parser(
         "startproject", help="Create a new project with template structure."
@@ -21,6 +25,12 @@ def init_parser_scaffold(subparsers):
     sub_parser_scaffold.add_argument(
         "project_name", type=str, nargs="?", help="Specify new project name."
     )
+    sub_parser_scaffold.add_argument(
+        "-venv",
+        dest="create_venv",
+        action="store_true",
+        help="Create virtual environment in the project, and install tep.",
+    )
     return sub_parser_scaffold
 
 
@@ -122,133 +132,25 @@ texttable==1.6.2
 
     create_file(os.path.join(project_name, "fixtures", "__init__.py"))
 
-    content = """#!/usr/bin/python
-# encoding=utf-8
-
-\"\"\" Can only be modified by the administrator. Only fixtures are provided.
-\"\"\"
-
-from tep.fixture import *
-
-
-@pytest.fixture
-def common_created_by_admin():
-    pass
-"""
-    create_file(os.path.join(project_name, "fixtures", "fixture_admin.py"), content)
-
-    content = """#!/usr/bin/python
-# encoding=utf-8
-
-from tep.dao import mysql_engine
-from tep.fixture import *
-
-
-@pytest.fixture(scope="session")
-def env_vars(config):
-    class Clazz(TepVars):
-        env = config["env"]
-
-        \"\"\"Variables define start\"\"\"
-        # Environment and variables
-        mapping = {
-            "qa": {
-                "domain": "https://qa.com",
-                "mysql_engine": mysql_engine("127.0.0.1",  # host
-                                             "2306",  # port
-                                             "root",  # username
-                                             "123456",  # password
-                                             "qa"),  # db_name
-            },
-            "release": {
-                "domain": "https://release.com",
-                "mysql_engine": mysql_engine("127.0.0.1",
-                                             "2306",
-                                             "root",
-                                             "123456",
-                                             "release"),
-            }
-            # Add your environment and variables
-        }
-        # Define properties for auto display
-        domain = mapping[env]["domain"]
-        mysql_engine = mapping[env]["mysql_engine"]
-        \"\"\"Variables define end\"\"\"
-
-    return Clazz()
-"""
-    create_file(os.path.join(project_name, "fixtures", "fixture_env_vars.py"), content)
-
-    content = """from tep.client import request
-from tep.fixture import *
-
-
-def _jwt_headers(token):
-    return {"Content-Type": "application/json", "authorization": f"Bearer {token}"}
-
-
-@pytest.fixture(scope="session")
-def login(env_vars):
-    # Code your login
-    logger.info("Administrator login")
-    response = request(
-        "post",
-        url=env_vars.domain + "/api/users/login",
-        headers={"Content-Type": "application/json"},
-        json={
-            "username": "admin",
-            "password": "123456",
-        }
-    )
-    assert response.status_code < 400
-    response_token = jmespath.search("token", response.json())
-
-    class Clazz:
-        token = response_token
-        jwt_headers = _jwt_headers(response_token)
-
-    return Clazz
-"""
-    create_file(os.path.join(project_name, "fixtures", "fixture_login.py"), content)
-
-    content = """#!/usr/bin/python
-# encoding=utf-8
-
-\"\"\" Please define your own fixture.
-\"\"\"
-
-from tep.fixture import *
-
-
-@pytest.fixture(scope="session")
-def env_vars_your_name(config):
-    class Clazz:
-        env = config["env"]
-
-        # Environment and variables
-        mapping = {
-            "qa": {
-                "your_var": "123",
-            },
-            "release": {
-                "your_var": "456",
-            }
-            # Add your environment and variables
-        }
-        # Define properties for auto display
-        your_var = mapping[env]["your_var"]
-
-    return Clazz()
-
-
-@pytest.fixture
-def share_your_name():
-    pass
-"""
-    create_file(os.path.join(project_name, "fixtures", "fixture_your_name.py"), content)
-
     create_file(os.path.join(project_name, "tests", "__init__.py"))
 
+    if ExtraArgument.create_venv:
+        os.chdir(project_name)
+        print("\nCreating virtual environment")
+        os.system("python -m venv .venv")
+        print("Created virtual environment: .venv")
+
+        print("Installing tep")
+        if platform.system().lower() == 'windows':
+            os.chdir(".venv")
+            os.chdir("Scripts")
+            os.system("pip install tep")
+        elif platform.system().lower() == 'linux':
+            os.chdir(".venv")
+            os.chdir("bin")
+            os.system("pip install tep")
+
 
 def main_scaffold(args):
+    ExtraArgument.create_venv = args.create_venv
     sys.exit(create_scaffold(args.project_name))
